@@ -21,7 +21,7 @@ sub connected {
     weaken($self);
     $client->reg_cb(MESSAGE => sub {
         my (undef, $body, $headers) = @_;
-        $self->output_to->consume($self->decode($body));
+        $self->output_to->consume($body);
     });
     my $subscribe_headers = {
         id => $id++,
@@ -68,7 +68,7 @@ To die.
 =head1 SPONSORSHIP
 
 This module exists due to the wonderful people at Suretec Systems Ltd.
-<http://www.suretecsystems.com/> who sponsored it's development for its
+<http://www.suretecsystems.com/> who sponsored its development for its
 VoIP division called SureVoIP <http://www.surevoip.co.uk/> for use with
 the SureVoIP API - 
 <http://www.surevoip.co.uk/support/wiki/api_documentation>
